#
# ksdb.py - like treedb.py, functions for handling a database of kickstarts
#
# Copyright 2006, 2007 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc. 
#

import os
from snake.kickstart import Kickstart

ksdb_dir = '/var/lib/snake/kickstarts'

def add(newfile,name=None,desc=None):
    '''Add the given file (or open file-like object) to the kickstart database.
    if the newfile is an open file-like object you can pass the 'name' param
    to give it a name.'''
    if hasattr(newfile,'read'):
        fp = newfile
        if not name:
            raise ValueError, "You need a name with a file-like object, yo."
    else:
        fp = open(newfile)
        if not name:
            (name,ext) = os.path.splitext(os.path.basename(newfile))

    write_data(fp.readlines(),name)

def write_data(data,name):
    '''Write the given kickstart data (a list of lines) to an entry in the 
    ksdb named 'name'.'''
    out = open(os.path.join(ksdb_dir,name+'.ks'),'w')
    for l in data:
        out.write(l)
    out.close()
    # FIXME: validate

def listkickstarts():
    '''Return a list of kickstart names and descriptions.'''
    kslist = list()
    for name in os.listdir(ksdb_dir):
        fname = os.path.join(ksdb_dir,name)
        (ksname,ext) = os.path.splitext(name)
        k = Kickstart()
        try:
            k.read(fname)
            kslist.append((ksname,k.description))
        except Exception, e:
            # Something went wrong while reading that kickstart.
            print "failed to read %s: %s" % (fname,e)
    return kslist

def generate(name,**kwargs):
    '''Generate a kickstart script, using the named template, modified by
    the given arguments.
    Accepted keyword arguments:
      commands=(list): Modify the template with the given kickstart commands.
                       The argument should be a list of command lines.
      version=(string): Generate a kickstart for the given kickstart language
                        version.
    '''
    # TODO: scripts=(list), packages=(list), tree=url|id, machine=id
    # XXX where does kernel commandline come in?
    k = Kickstart(version=kwargs.get("version","devel"))
    k.read(os.path.join(ksdb_dir,"%s.ks" % name), reset=False)
    if 'commands' in kwargs:
        for l in kwargs['commands']:
            k.handlecommand(l)
    return str(k)

def remove(ks):
    '''Remove the named kickstart from the database'''
    os.unlink(os.path.join(ksdb_dir,"%s.ks" % ks))
