#
# Copyright 2006, 2007 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc. 
#

from lxml import etree

class LabQuery(object):
    def __init__(self, index):
        self.et = etree.parse(index)
        self.et.xinclude()
        self.root = self.et.getroot()

    def query(self, expression):
        return self.root.xpath(expression)

    def nick_to_id(self, nickname):
        return self.root.xpath('/lab/machine[nickname = "%s"]/@id' % nickname)

    def fqdn_to_id(self, fqdn):
        return self.root.xpath('/lab/machine[fqdn = "%s"]/@id' % fqdn)

    def mac_to_id(self, mac):
        return self.root.xpath('/lab/machine[fingerprint = "%s"]/@id' % mac)

    def id_to_info(self, id):
        info = {}
        for node in self.query('/lab/machine[@id = "%s"]' % id):
            info['nickname'] = node.xpath('nickname')[0].text
            info['fqdn'] = node.xpath('fqdn')[0].text
            info['bootargs'] = node.xpath('bootargs')[0].text
            info['fingerprints'] = [i.text for i in node.xpath('fingerprint')]
            info['ksdevice'] = node.xpath('ksdevice')[0].text
        return info
